@@ -1,4 +1,4 @@
 from . import sklearn
 from . import util
-from .connector import Experiment, Dataset
+from .connector import Experiment, Dataset, Deployment
 from .main import generate_experiment
