@@ -26,14 +26,16 @@ def get_typed_params(params: dict) -> dict:
             and params[param] is not None
         ):
             try:
-                params[param] = int(params[param])
+                if int(params[param]) == float(params[param]):
+                    params[param] = int(params[param])
+                else:
+                    params[param] = float(params[param])
             except:
                 try:
-                    params[param] = float(params[param])
+                    params[param] = int(params[param])
                 except:
                     try:
                         params[param] = str(params[param])
                     except:
                         print("Error generating type for parameter: ", param)
-
     return params
